# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: web_rtc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from . import device_info_pb2 as device__info__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='web_rtc.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\rweb_rtc.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x11\x64\x65vice_info.proto\x1a\x15scalapb/scalapb.proto\"\x81\x01\n\x1cUpdateIncomingCallDeprecated\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x41\n\rattempt_index\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\"\xca\x02\n\x12UpdateIncomingCall\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x65vent_bus_id\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x04peer\x18\x03 \x01(\x0b\x32\x0c.dialog.Peer\x12@\n\x0c\x64isplay_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x41\n\rattempt_index\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x08out_peer\x18\x06 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05video\x18\x07 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"v\n\x11UpdateCallHandled\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x41\n\rattempt_index\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\"\xa3\x01\n\x12UpdateCallDisposed\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x41\n\rattempt_index\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x06reason\x18\x03 \x01(\x0e\x32\x1a.dialog.CallDisposedReason\"R\n\x12RequestGetCallInfo\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xe4\x01\n\x13ResponseGetCallInfo\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12$\n\x06groups\x18\x02 \x03(\x0b\x32\x14.dialog.GroupOutPeer\x12\"\n\x05users\x18\x03 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12\x14\n\x0c\x65vent_bus_id\x18\x04 \x01(\t\x12\x32\n\x0c\x64isplay_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xca\x03\n\x0c\x43\x61llLogEntry\x12\x19\n\x02id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tcall_date\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x31\n\tinitiator\x18\x03 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x31\n\trecipient\x18\x04 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x08\x61nswered\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12,\n\x08\x66inished\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12@\n\x0c\x64isplay_name\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12,\n\x08rejected\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8f\x01\n\x10RequestLoadCalls\x12?\n\x0bnext_offset\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05limit\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xd3\x01\n\x11ResponseLoadCalls\x12#\n\x05\x63\x61lls\x18\x01 \x03(\x0b\x32\x14.dialog.CallLogEntry\x12\"\n\x05users\x18\x02 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12$\n\x06groups\x18\x03 \x03(\x0b\x32\x14.dialog.GroupOutPeer\x12\x30\n\x0bnext_offset\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"l\n\rRequestDoCall\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x0f\n\x07timeout\x18\x02 \x01(\x03:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"i\n\x0eResponseDoCall\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x65vent_bus_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\x03:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"O\n\x0fRequestJoinCall\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"{\n\x11RequestRejectCall\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12(\n\x06reason\x18\x02 \x01(\x0e\x32\x18.dialog.RejectCallReason:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"Q\n\x11RequestDeleteCall\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9e\x01\n\x1cRequestChangeCallDisplayName\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0c\x64isplay_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa5\x01\n\tICEServer\x12\x1a\n\x03url\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x08username\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12>\n\ncredential\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\"F\n\x0cICECandidate\x12\x18\n\x10sdp_m_line_index\x18\x01 \x01(\x05\x12\x0f\n\x07sdp_mid\x18\x02 \x01(\t\x12\x0b\n\x03sdp\x18\x03 \x01(\t\"\xc3\x06\n\x0fWebRTCSignaling\x12.\n\radvertiseSelf\x18\x01 \x01(\x0b\x32\x15.dialog.AdvertiseSelfH\x00\x12\x32\n\x0f\x61\x64vertiseMaster\x18\x02 \x01(\x0b\x32\x17.dialog.AdvertiseMasterH\x00\x12.\n\radvertisePeer\x18\x03 \x01(\x0b\x32\x15.dialog.AdvertisePeerH\x00\x12&\n\tcandidate\x18\x04 \x01(\x0b\x32\x11.dialog.CandidateH\x00\x12\x32\n\x0fgotICECandidate\x18\x05 \x01(\x0b\x32\x17.dialog.GotICECandidateH\x00\x12<\n\x14removedICECandidates\x18\x06 \x01(\x0b\x32\x1c.dialog.RemovedICECandidatesH\x00\x12\x1e\n\x05offer\x18\x07 \x01(\x0b\x32\r.dialog.OfferH\x00\x12 \n\x06\x61nswer\x18\x08 \x01(\x0b\x32\x0e.dialog.AnswerH\x00\x12&\n\tneedOffer\x18\t \x01(\x0b\x32\x11.dialog.NeedOfferH\x00\x12@\n\x16negotinationSuccessful\x18\n \x01(\x0b\x32\x1e.dialog.NegotinationSuccessfulH\x00\x12\x34\n\x10\x65nableConnection\x18\x0b \x01(\x0b\x32\x18.dialog.EnableConnectionH\x00\x12>\n\x15onRenegotiationNeeded\x18\x0c \x01(\x0b\x32\x1d.dialog.OnRenegotiationNeededH\x00\x12,\n\x0c\x63loseSession\x18\r \x01(\x0b\x32\x14.dialog.CloseSessionH\x00\x12\x30\n\x0eneedDisconnect\x18\x0e \x01(\x0b\x32\x16.dialog.NeedDisconnectH\x00\x12\x1c\n\x04\x64TMF\x18\x0f \x01(\x0b\x32\x0c.dialog.DTMFH\x00\x12&\n\tcallStats\x18\x10 \x01(\x0b\x32\x11.dialog.CallStatsH\x00\x12\x32\n\x0f\x63\x61llNameChanged\x18\x11 \x01(\x0b\x32\x17.dialog.CallNameChangedH\x00\x42\x06\n\x04\x62ody\"K\n\rAdvertiseSelf\x12:\n\rpeer_settings\x18\x01 \x01(\x0b\x32\x14.dialog.PeerSettingsB\r\x8a\xea\x30\t\n\x07visible\"\xba\x01\n\x0f\x41\x64vertiseMaster\x12\x30\n\x06server\x18\x01 \x03(\x0b\x32\x11.dialog.ICEServerB\r\x8a\xea\x30\t\n\x07visible\x12\x44\n\x10\x63\x61ll_api_version\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12/\n\tcall_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa4\x01\n\rAdvertisePeer\x12 \n\tdevice_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\rpeer_settings\x18\x02 \x01(\x0b\x32\x14.dialog.PeerSettingsB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\x0bice_servers\x18\x03 \x03(\x0b\x32\x11.dialog.ICEServerB\r\x8a\xea\x30\t\n\x07visible\"\x83\x01\n\tCandidate\x12!\n\nsession_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05index\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x19\n\x02id\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03sdp\x18\x04 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"N\n\x0fGotICECandidate\x12\x12\n\nsession_id\x18\x01 \x01(\x03\x12\'\n\tcandidate\x18\x02 \x01(\x0b\x32\x14.dialog.ICECandidate\"S\n\x14RemovedICECandidates\x12\x12\n\nsession_id\x18\x01 \x01(\x03\x12\'\n\tcandidate\x18\x02 \x03(\x0b\x32\x14.dialog.ICECandidate\"\x82\x01\n\x05Offer\x12!\n\nsession_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03sdp\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12:\n\rpeer_settings\x18\x03 \x01(\x0b\x32\x14.dialog.PeerSettingsB\r\x8a\xea\x30\t\n\x07visible\"G\n\x06\x41nswer\x12!\n\nsession_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03sdp\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"\x89\x01\n\tNeedOffer\x12\x1d\n\x06\x64\x65vice\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsession_id\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\rpeer_settings\x18\x03 \x01(\x0b\x32\x14.dialog.PeerSettingsB\r\x8a\xea\x30\t\n\x07visible\"Z\n\x16NegotinationSuccessful\x12\x1d\n\x06\x64\x65vice\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsession_id\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"T\n\x10\x45nableConnection\x12\x1d\n\x06\x64\x65vice\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsession_id\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"Y\n\x15OnRenegotiationNeeded\x12\x1d\n\x06\x64\x65vice\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsession_id\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"P\n\x0c\x43loseSession\x12\x1d\n\x06\x64\x65vice\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nsession_id\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\".\n\x0eNeedDisconnect\x12\x1c\n\x06\x64\x65vice\x18\x01 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06hidden\"V\n\x04\x44TMF\x12-\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x10.dialog.DTMFCodeB\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08\x64uration\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"]\n\tCallStats\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x15.dialog.CallStatsTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"B\n\x0f\x43\x61llNameChanged\x12/\n\tcall_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x90\x01\n\nActiveCall\x12\x1e\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12)\n\x04peer\x18\x02 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x0c\x63\x61ll_members\x18\x03 \x03(\x0b\x32\x12.dialog.CallMemberB\r\x8a\xea\x30\t\n\x07visible\"\xc1\x03\n\x15\x43\x61llMemberStateHolder\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32\x17.dialog.CallMemberStateB\r\x8a\xea\x30\t\n\x07visible\x12\x46\n\x13\x66\x61llback_is_ringing\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12H\n\x15\x66\x61llback_is_connected\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12I\n\x16\x66\x61llback_is_connecting\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12N\n\x1b\x66\x61llback_is_ringing_reached\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x44\n\x11\x66\x61llback_is_ended\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"i\n\nCallMember\x12\x1e\n\x07user_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12;\n\x05state\x18\x03 \x01(\x0b\x32\x1d.dialog.CallMemberStateHolderB\r\x8a\xea\x30\t\n\x07visible\"\x92\x02\n\x0cPeerSettings\x12\x42\n\x0f\x63\x61n_pre_connect\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0bsends_offer\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x46\n\x13wait_for_candidates\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0b\x63lient_info\x18\x07 \x01(\x0b\x32\x12.dialog.ClientInfoB\r\x8a\xea\x30\t\n\x07visible*\xb7\x01\n\x12\x43\x61llDisposedReason\x12\x1e\n\x1a\x43\x41LLDISPOSEDREASON_UNKNOWN\x10\x00\x12\x1f\n\x1b\x43\x41LLDISPOSEDREASON_REJECTED\x10\x01\x12\x1b\n\x17\x43\x41LLDISPOSEDREASON_BUSY\x10\x02\x12\x1c\n\x18\x43\x41LLDISPOSEDREASON_ENDED\x10\x03\x12%\n!CALLDISPOSEDREASON_ANSWER_TIMEOUT\x10\x04*i\n\x10RejectCallReason\x12\x1c\n\x18REJECTCALLREASON_UNKNOWN\x10\x00\x12\x1c\n\x18REJECTCALLREASON_DECLINE\x10\x01\x12\x19\n\x15REJECTCALLREASON_BUSY\x10\x02*\xc9\x02\n\x08\x44TMFCode\x12\x14\n\x10\x44TMFCODE_UNKNOWN\x10\x00\x12\x11\n\rDTMFCODE_ZERO\x10\x01\x12\x10\n\x0c\x44TMFCODE_ONE\x10\x02\x12\x10\n\x0c\x44TMFCODE_TWO\x10\x03\x12\x12\n\x0e\x44TMFCODE_THREE\x10\x04\x12\x11\n\rDTMFCODE_FOUR\x10\x05\x12\x11\n\rDTMFCODE_FIVE\x10\x06\x12\x10\n\x0c\x44TMFCODE_SIX\x10\x07\x12\x12\n\x0e\x44TMFCODE_SEVEN\x10\x08\x12\x12\n\x0e\x44TMFCODE_EIGHT\x10\t\x12\x11\n\rDTMFCODE_NINE\x10\n\x12\x15\n\x11\x44TMFCODE_ASTERISK\x10\x0b\x12\x12\n\x0e\x44TMFCODE_POUND\x10\x0c\x12\x0e\n\nDTMFCODE_A\x10\r\x12\x0e\n\nDTMFCODE_B\x10\x0e\x12\x0e\n\nDTMFCODE_C\x10\x0f\x12\x0e\n\nDTMFCODE_D\x10\x10*\x81\x04\n\rCallStatsType\x12\x19\n\x15\x43\x41LLSTATSTYPE_UNKNOWN\x10\x00\x12-\n)CALLSTATSTYPE_TURN_SERVER_ROUND_TRIP_TIME\x10\x01\x12\'\n#CALLSTATSTYPE_ICE_CONNECTION_FAILED\x10\x02\x12*\n&CALLSTATSTYPE_ICE_CONNECTION_CONNECTED\x10\x03\x12\x30\n,CALLSTATSTYPE_ICE_CONNECTION_DID_NOT_CONNECT\x10\x04\x12/\n+CALLSTATSTYPE_ICE_CONNECTION_CONNECTED_TIME\x10\x05\x12\x36\n2CALLSTATSTYPE_PEER_CONNECTION_CREATE_ANSWER_FAILED\x10\x06\x12\x35\n1CALLSTATSTYPE_PEER_CONNECTION_CREATE_OFFER_FAILED\x10\x07\x12?\n;CALLSTATSTYPE_PEER_CONNECTION_SET_REMOTE_DESCRIPTION_FAILED\x10\x08\x12>\n:CALLSTATSTYPE_PEER_CONNECTION_SET_LOCAL_DESCRIPTION_FAILED\x10\t*\xca\x01\n\x0f\x43\x61llMemberState\x12\x1b\n\x17\x43\x41LLMEMBERSTATE_UNKNOWN\x10\x00\x12\x1b\n\x17\x43\x41LLMEMBERSTATE_RINGING\x10\x01\x12#\n\x1f\x43\x41LLMEMBERSTATE_RINGING_REACHED\x10\x04\x12\x1e\n\x1a\x43\x41LLMEMBERSTATE_CONNECTING\x10\x02\x12\x1d\n\x19\x43\x41LLMEMBERSTATE_CONNECTED\x10\x03\x12\x19\n\x15\x43\x41LLMEMBERSTATE_ENDED\x10\x05\x32\xf0\x05\n\x06WebRTC\x12n\n\x0bGetCallInfo\x12\x1a.dialog.RequestGetCallInfo\x1a\x1b.dialog.ResponseGetCallInfo\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/WebRTC/GetCallInfo:\x01*\x12\x66\n\tLoadCalls\x12\x18.dialog.RequestLoadCalls\x1a\x19.dialog.ResponseLoadCalls\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/grpc/WebRTC/LoadCalls:\x01*\x12Z\n\x06\x44oCall\x12\x15.dialog.RequestDoCall\x1a\x16.dialog.ResponseDoCall\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/grpc/WebRTC/DoCall:\x01*\x12^\n\x08JoinCall\x12\x17.dialog.RequestJoinCall\x1a\x14.dialog.ResponseVoid\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/grpc/WebRTC/JoinCall:\x01*\x12\x64\n\nRejectCall\x12\x19.dialog.RequestRejectCall\x1a\x14.dialog.ResponseVoid\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/WebRTC/RejectCall:\x01*\x12\x85\x01\n\x15\x43hangeCallDisplayName\x12$.dialog.RequestChangeCallDisplayName\x1a\x14.dialog.ResponseVoid\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/WebRTC/ChangeCallDisplayName:\x01*\x12\x64\n\nDeleteCall\x12\x19.dialog.RequestDeleteCall\x1a\x14.dialog.ResponseVoid\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/WebRTC/DeleteCall:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,device__info__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_CALLDISPOSEDREASON = _descriptor.EnumDescriptor(
  name='CallDisposedReason',
  full_name='dialog.CallDisposedReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CALLDISPOSEDREASON_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLDISPOSEDREASON_REJECTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLDISPOSEDREASON_BUSY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLDISPOSEDREASON_ENDED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLDISPOSEDREASON_ANSWER_TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6526,
  serialized_end=6709,
)
_sym_db.RegisterEnumDescriptor(_CALLDISPOSEDREASON)

CallDisposedReason = enum_type_wrapper.EnumTypeWrapper(_CALLDISPOSEDREASON)
_REJECTCALLREASON = _descriptor.EnumDescriptor(
  name='RejectCallReason',
  full_name='dialog.RejectCallReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REJECTCALLREASON_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTCALLREASON_DECLINE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTCALLREASON_BUSY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6711,
  serialized_end=6816,
)
_sym_db.RegisterEnumDescriptor(_REJECTCALLREASON)

RejectCallReason = enum_type_wrapper.EnumTypeWrapper(_REJECTCALLREASON)
_DTMFCODE = _descriptor.EnumDescriptor(
  name='DTMFCode',
  full_name='dialog.DTMFCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_ZERO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_ONE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_TWO', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_THREE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_FOUR', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_FIVE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_SIX', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_SEVEN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_EIGHT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_NINE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_ASTERISK', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_POUND', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_A', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_B', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_C', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DTMFCODE_D', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6819,
  serialized_end=7148,
)
_sym_db.RegisterEnumDescriptor(_DTMFCODE)

DTMFCode = enum_type_wrapper.EnumTypeWrapper(_DTMFCODE)
_CALLSTATSTYPE = _descriptor.EnumDescriptor(
  name='CallStatsType',
  full_name='dialog.CallStatsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_TURN_SERVER_ROUND_TRIP_TIME', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_ICE_CONNECTION_FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_ICE_CONNECTION_CONNECTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_ICE_CONNECTION_DID_NOT_CONNECT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_ICE_CONNECTION_CONNECTED_TIME', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_PEER_CONNECTION_CREATE_ANSWER_FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_PEER_CONNECTION_CREATE_OFFER_FAILED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_PEER_CONNECTION_SET_REMOTE_DESCRIPTION_FAILED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLSTATSTYPE_PEER_CONNECTION_SET_LOCAL_DESCRIPTION_FAILED', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7151,
  serialized_end=7664,
)
_sym_db.RegisterEnumDescriptor(_CALLSTATSTYPE)

CallStatsType = enum_type_wrapper.EnumTypeWrapper(_CALLSTATSTYPE)
_CALLMEMBERSTATE = _descriptor.EnumDescriptor(
  name='CallMemberState',
  full_name='dialog.CallMemberState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CALLMEMBERSTATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLMEMBERSTATE_RINGING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLMEMBERSTATE_RINGING_REACHED', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLMEMBERSTATE_CONNECTING', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLMEMBERSTATE_CONNECTED', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLMEMBERSTATE_ENDED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7667,
  serialized_end=7869,
)
_sym_db.RegisterEnumDescriptor(_CALLMEMBERSTATE)

CallMemberState = enum_type_wrapper.EnumTypeWrapper(_CALLMEMBERSTATE)
CALLDISPOSEDREASON_UNKNOWN = 0
CALLDISPOSEDREASON_REJECTED = 1
CALLDISPOSEDREASON_BUSY = 2
CALLDISPOSEDREASON_ENDED = 3
CALLDISPOSEDREASON_ANSWER_TIMEOUT = 4
REJECTCALLREASON_UNKNOWN = 0
REJECTCALLREASON_DECLINE = 1
REJECTCALLREASON_BUSY = 2
DTMFCODE_UNKNOWN = 0
DTMFCODE_ZERO = 1
DTMFCODE_ONE = 2
DTMFCODE_TWO = 3
DTMFCODE_THREE = 4
DTMFCODE_FOUR = 5
DTMFCODE_FIVE = 6
DTMFCODE_SIX = 7
DTMFCODE_SEVEN = 8
DTMFCODE_EIGHT = 9
DTMFCODE_NINE = 10
DTMFCODE_ASTERISK = 11
DTMFCODE_POUND = 12
DTMFCODE_A = 13
DTMFCODE_B = 14
DTMFCODE_C = 15
DTMFCODE_D = 16
CALLSTATSTYPE_UNKNOWN = 0
CALLSTATSTYPE_TURN_SERVER_ROUND_TRIP_TIME = 1
CALLSTATSTYPE_ICE_CONNECTION_FAILED = 2
CALLSTATSTYPE_ICE_CONNECTION_CONNECTED = 3
CALLSTATSTYPE_ICE_CONNECTION_DID_NOT_CONNECT = 4
CALLSTATSTYPE_ICE_CONNECTION_CONNECTED_TIME = 5
CALLSTATSTYPE_PEER_CONNECTION_CREATE_ANSWER_FAILED = 6
CALLSTATSTYPE_PEER_CONNECTION_CREATE_OFFER_FAILED = 7
CALLSTATSTYPE_PEER_CONNECTION_SET_REMOTE_DESCRIPTION_FAILED = 8
CALLSTATSTYPE_PEER_CONNECTION_SET_LOCAL_DESCRIPTION_FAILED = 9
CALLMEMBERSTATE_UNKNOWN = 0
CALLMEMBERSTATE_RINGING = 1
CALLMEMBERSTATE_RINGING_REACHED = 4
CALLMEMBERSTATE_CONNECTING = 2
CALLMEMBERSTATE_CONNECTED = 3
CALLMEMBERSTATE_ENDED = 5



_UPDATEINCOMINGCALLDEPRECATED = _descriptor.Descriptor(
  name='UpdateIncomingCallDeprecated',
  full_name='dialog.UpdateIncomingCallDeprecated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.UpdateIncomingCallDeprecated.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempt_index', full_name='dialog.UpdateIncomingCallDeprecated.attempt_index', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=312,
)


_UPDATEINCOMINGCALL = _descriptor.Descriptor(
  name='UpdateIncomingCall',
  full_name='dialog.UpdateIncomingCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.UpdateIncomingCall.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_bus_id', full_name='dialog.UpdateIncomingCall.event_bus_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateIncomingCall.peer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='dialog.UpdateIncomingCall.display_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempt_index', full_name='dialog.UpdateIncomingCall.attempt_index', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_peer', full_name='dialog.UpdateIncomingCall.out_peer', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video', full_name='dialog.UpdateIncomingCall.video', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=645,
)


_UPDATECALLHANDLED = _descriptor.Descriptor(
  name='UpdateCallHandled',
  full_name='dialog.UpdateCallHandled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.UpdateCallHandled.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempt_index', full_name='dialog.UpdateCallHandled.attempt_index', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=765,
)


_UPDATECALLDISPOSED = _descriptor.Descriptor(
  name='UpdateCallDisposed',
  full_name='dialog.UpdateCallDisposed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.UpdateCallDisposed.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempt_index', full_name='dialog.UpdateCallDisposed.attempt_index', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='dialog.UpdateCallDisposed.reason', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=768,
  serialized_end=931,
)


_REQUESTGETCALLINFO = _descriptor.Descriptor(
  name='RequestGetCallInfo',
  full_name='dialog.RequestGetCallInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.RequestGetCallInfo.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=1015,
)


_RESPONSEGETCALLINFO = _descriptor.Descriptor(
  name='ResponseGetCallInfo',
  full_name='dialog.ResponseGetCallInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ResponseGetCallInfo.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseGetCallInfo.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseGetCallInfo.users', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_bus_id', full_name='dialog.ResponseGetCallInfo.event_bus_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='dialog.ResponseGetCallInfo.display_name', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1246,
)


_CALLLOGENTRY = _descriptor.Descriptor(
  name='CallLogEntry',
  full_name='dialog.CallLogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.CallLogEntry.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_date', full_name='dialog.CallLogEntry.call_date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initiator', full_name='dialog.CallLogEntry.initiator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recipient', full_name='dialog.CallLogEntry.recipient', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='dialog.CallLogEntry.duration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answered', full_name='dialog.CallLogEntry.answered', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finished', full_name='dialog.CallLogEntry.finished', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='dialog.CallLogEntry.display_name', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rejected', full_name='dialog.CallLogEntry.rejected', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1707,
)


_REQUESTLOADCALLS = _descriptor.Descriptor(
  name='RequestLoadCalls',
  full_name='dialog.RequestLoadCalls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_offset', full_name='dialog.RequestLoadCalls.next_offset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadCalls.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1853,
)


_RESPONSELOADCALLS = _descriptor.Descriptor(
  name='ResponseLoadCalls',
  full_name='dialog.ResponseLoadCalls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calls', full_name='dialog.ResponseLoadCalls.calls', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadCalls.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseLoadCalls.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_offset', full_name='dialog.ResponseLoadCalls.next_offset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1856,
  serialized_end=2067,
)


_REQUESTDOCALL = _descriptor.Descriptor(
  name='RequestDoCall',
  full_name='dialog.RequestDoCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestDoCall.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestDoCall.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2069,
  serialized_end=2177,
)


_RESPONSEDOCALL = _descriptor.Descriptor(
  name='ResponseDoCall',
  full_name='dialog.ResponseDoCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.ResponseDoCall.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_bus_id', full_name='dialog.ResponseDoCall.event_bus_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.ResponseDoCall.device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2179,
  serialized_end=2284,
)


_REQUESTJOINCALL = _descriptor.Descriptor(
  name='RequestJoinCall',
  full_name='dialog.RequestJoinCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.RequestJoinCall.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2286,
  serialized_end=2365,
)


_REQUESTREJECTCALL = _descriptor.Descriptor(
  name='RequestRejectCall',
  full_name='dialog.RequestRejectCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.RequestRejectCall.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='dialog.RequestRejectCall.reason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2367,
  serialized_end=2490,
)


_REQUESTDELETECALL = _descriptor.Descriptor(
  name='RequestDeleteCall',
  full_name='dialog.RequestDeleteCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.RequestDeleteCall.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2492,
  serialized_end=2573,
)


_REQUESTCHANGECALLDISPLAYNAME = _descriptor.Descriptor(
  name='RequestChangeCallDisplayName',
  full_name='dialog.RequestChangeCallDisplayName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.RequestChangeCallDisplayName.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='dialog.RequestChangeCallDisplayName.display_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2576,
  serialized_end=2734,
)


_ICESERVER = _descriptor.Descriptor(
  name='ICEServer',
  full_name='dialog.ICEServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ICEServer.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='dialog.ICEServer.username', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='credential', full_name='dialog.ICEServer.credential', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2737,
  serialized_end=2902,
)


_ICECANDIDATE = _descriptor.Descriptor(
  name='ICECandidate',
  full_name='dialog.ICECandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdp_m_line_index', full_name='dialog.ICECandidate.sdp_m_line_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdp_mid', full_name='dialog.ICECandidate.sdp_mid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdp', full_name='dialog.ICECandidate.sdp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2904,
  serialized_end=2974,
)


_WEBRTCSIGNALING = _descriptor.Descriptor(
  name='WebRTCSignaling',
  full_name='dialog.WebRTCSignaling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='advertiseSelf', full_name='dialog.WebRTCSignaling.advertiseSelf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertiseMaster', full_name='dialog.WebRTCSignaling.advertiseMaster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertisePeer', full_name='dialog.WebRTCSignaling.advertisePeer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='dialog.WebRTCSignaling.candidate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gotICECandidate', full_name='dialog.WebRTCSignaling.gotICECandidate', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removedICECandidates', full_name='dialog.WebRTCSignaling.removedICECandidates', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer', full_name='dialog.WebRTCSignaling.offer', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer', full_name='dialog.WebRTCSignaling.answer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needOffer', full_name='dialog.WebRTCSignaling.needOffer', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negotinationSuccessful', full_name='dialog.WebRTCSignaling.negotinationSuccessful', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enableConnection', full_name='dialog.WebRTCSignaling.enableConnection', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onRenegotiationNeeded', full_name='dialog.WebRTCSignaling.onRenegotiationNeeded', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closeSession', full_name='dialog.WebRTCSignaling.closeSession', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needDisconnect', full_name='dialog.WebRTCSignaling.needDisconnect', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dTMF', full_name='dialog.WebRTCSignaling.dTMF', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callStats', full_name='dialog.WebRTCSignaling.callStats', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callNameChanged', full_name='dialog.WebRTCSignaling.callNameChanged', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.WebRTCSignaling.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2977,
  serialized_end=3812,
)


_ADVERTISESELF = _descriptor.Descriptor(
  name='AdvertiseSelf',
  full_name='dialog.AdvertiseSelf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_settings', full_name='dialog.AdvertiseSelf.peer_settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3814,
  serialized_end=3889,
)


_ADVERTISEMASTER = _descriptor.Descriptor(
  name='AdvertiseMaster',
  full_name='dialog.AdvertiseMaster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='dialog.AdvertiseMaster.server', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_api_version', full_name='dialog.AdvertiseMaster.call_api_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_name', full_name='dialog.AdvertiseMaster.call_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3892,
  serialized_end=4078,
)


_ADVERTISEPEER = _descriptor.Descriptor(
  name='AdvertisePeer',
  full_name='dialog.AdvertisePeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.AdvertisePeer.device_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_settings', full_name='dialog.AdvertisePeer.peer_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ice_servers', full_name='dialog.AdvertisePeer.ice_servers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4081,
  serialized_end=4245,
)


_CANDIDATE = _descriptor.Descriptor(
  name='Candidate',
  full_name='dialog.Candidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.Candidate.session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='dialog.Candidate.index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Candidate.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdp', full_name='dialog.Candidate.sdp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4248,
  serialized_end=4379,
)


_GOTICECANDIDATE = _descriptor.Descriptor(
  name='GotICECandidate',
  full_name='dialog.GotICECandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.GotICECandidate.session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='dialog.GotICECandidate.candidate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4381,
  serialized_end=4459,
)


_REMOVEDICECANDIDATES = _descriptor.Descriptor(
  name='RemovedICECandidates',
  full_name='dialog.RemovedICECandidates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.RemovedICECandidates.session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='dialog.RemovedICECandidates.candidate', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4461,
  serialized_end=4544,
)


_OFFER = _descriptor.Descriptor(
  name='Offer',
  full_name='dialog.Offer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.Offer.session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdp', full_name='dialog.Offer.sdp', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_settings', full_name='dialog.Offer.peer_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4547,
  serialized_end=4677,
)


_ANSWER = _descriptor.Descriptor(
  name='Answer',
  full_name='dialog.Answer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.Answer.session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdp', full_name='dialog.Answer.sdp', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4679,
  serialized_end=4750,
)


_NEEDOFFER = _descriptor.Descriptor(
  name='NeedOffer',
  full_name='dialog.NeedOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='dialog.NeedOffer.device', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.NeedOffer.session_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_settings', full_name='dialog.NeedOffer.peer_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4753,
  serialized_end=4890,
)


_NEGOTINATIONSUCCESSFUL = _descriptor.Descriptor(
  name='NegotinationSuccessful',
  full_name='dialog.NegotinationSuccessful',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='dialog.NegotinationSuccessful.device', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.NegotinationSuccessful.session_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4892,
  serialized_end=4982,
)


_ENABLECONNECTION = _descriptor.Descriptor(
  name='EnableConnection',
  full_name='dialog.EnableConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='dialog.EnableConnection.device', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.EnableConnection.session_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4984,
  serialized_end=5068,
)


_ONRENEGOTIATIONNEEDED = _descriptor.Descriptor(
  name='OnRenegotiationNeeded',
  full_name='dialog.OnRenegotiationNeeded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='dialog.OnRenegotiationNeeded.device', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.OnRenegotiationNeeded.session_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5070,
  serialized_end=5159,
)


_CLOSESESSION = _descriptor.Descriptor(
  name='CloseSession',
  full_name='dialog.CloseSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='dialog.CloseSession.device', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='dialog.CloseSession.session_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5161,
  serialized_end=5241,
)


_NEEDDISCONNECT = _descriptor.Descriptor(
  name='NeedDisconnect',
  full_name='dialog.NeedDisconnect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='dialog.NeedDisconnect.device', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5243,
  serialized_end=5289,
)


_DTMF = _descriptor.Descriptor(
  name='DTMF',
  full_name='dialog.DTMF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.DTMF.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='dialog.DTMF.duration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5291,
  serialized_end=5377,
)


_CALLSTATS = _descriptor.Descriptor(
  name='CallStats',
  full_name='dialog.CallStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.CallStats.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.CallStats.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5379,
  serialized_end=5472,
)


_CALLNAMECHANGED = _descriptor.Descriptor(
  name='CallNameChanged',
  full_name='dialog.CallNameChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_name', full_name='dialog.CallNameChanged.call_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5474,
  serialized_end=5540,
)


_ACTIVECALL = _descriptor.Descriptor(
  name='ActiveCall',
  full_name='dialog.ActiveCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_id', full_name='dialog.ActiveCall.call_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ActiveCall.peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_members', full_name='dialog.ActiveCall.call_members', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5543,
  serialized_end=5687,
)


_CALLMEMBERSTATEHOLDER = _descriptor.Descriptor(
  name='CallMemberStateHolder',
  full_name='dialog.CallMemberStateHolder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.CallMemberStateHolder.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_is_ringing', full_name='dialog.CallMemberStateHolder.fallback_is_ringing', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_is_connected', full_name='dialog.CallMemberStateHolder.fallback_is_connected', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_is_connecting', full_name='dialog.CallMemberStateHolder.fallback_is_connecting', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_is_ringing_reached', full_name='dialog.CallMemberStateHolder.fallback_is_ringing_reached', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_is_ended', full_name='dialog.CallMemberStateHolder.fallback_is_ended', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5690,
  serialized_end=6139,
)


_CALLMEMBER = _descriptor.Descriptor(
  name='CallMember',
  full_name='dialog.CallMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.CallMember.user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.CallMember.state', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6141,
  serialized_end=6246,
)


_PEERSETTINGS = _descriptor.Descriptor(
  name='PeerSettings',
  full_name='dialog.PeerSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_pre_connect', full_name='dialog.PeerSettings.can_pre_connect', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sends_offer', full_name='dialog.PeerSettings.sends_offer', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_for_candidates', full_name='dialog.PeerSettings.wait_for_candidates', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_info', full_name='dialog.PeerSettings.client_info', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6249,
  serialized_end=6523,
)

_UPDATEINCOMINGCALLDEPRECATED.fields_by_name['attempt_index'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATEINCOMINGCALL.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEINCOMINGCALL.fields_by_name['display_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEINCOMINGCALL.fields_by_name['attempt_index'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATEINCOMINGCALL.fields_by_name['out_peer'].message_type = peers__pb2._OUTPEER
_UPDATECALLHANDLED.fields_by_name['attempt_index'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATECALLDISPOSED.fields_by_name['attempt_index'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_UPDATECALLDISPOSED.fields_by_name['reason'].enum_type = _CALLDISPOSEDREASON
_RESPONSEGETCALLINFO.fields_by_name['peer'].message_type = peers__pb2._PEER
_RESPONSEGETCALLINFO.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSEGETCALLINFO.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_RESPONSEGETCALLINFO.fields_by_name['display_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLLOGENTRY.fields_by_name['initiator'].message_type = peers__pb2._OUTPEER
_CALLLOGENTRY.fields_by_name['recipient'].message_type = peers__pb2._OUTPEER
_CALLLOGENTRY.fields_by_name['duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CALLLOGENTRY.fields_by_name['answered'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLLOGENTRY.fields_by_name['finished'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLLOGENTRY.fields_by_name['display_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLLOGENTRY.fields_by_name['rejected'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REQUESTLOADCALLS.fields_by_name['next_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSELOADCALLS.fields_by_name['calls'].message_type = _CALLLOGENTRY
_RESPONSELOADCALLS.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADCALLS.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSELOADCALLS.fields_by_name['next_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_REQUESTDOCALL.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTREJECTCALL.fields_by_name['reason'].enum_type = _REJECTCALLREASON
_REQUESTCHANGECALLDISPLAYNAME.fields_by_name['display_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ICESERVER.fields_by_name['username'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ICESERVER.fields_by_name['credential'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_WEBRTCSIGNALING.fields_by_name['advertiseSelf'].message_type = _ADVERTISESELF
_WEBRTCSIGNALING.fields_by_name['advertiseMaster'].message_type = _ADVERTISEMASTER
_WEBRTCSIGNALING.fields_by_name['advertisePeer'].message_type = _ADVERTISEPEER
_WEBRTCSIGNALING.fields_by_name['candidate'].message_type = _CANDIDATE
_WEBRTCSIGNALING.fields_by_name['gotICECandidate'].message_type = _GOTICECANDIDATE
_WEBRTCSIGNALING.fields_by_name['removedICECandidates'].message_type = _REMOVEDICECANDIDATES
_WEBRTCSIGNALING.fields_by_name['offer'].message_type = _OFFER
_WEBRTCSIGNALING.fields_by_name['answer'].message_type = _ANSWER
_WEBRTCSIGNALING.fields_by_name['needOffer'].message_type = _NEEDOFFER
_WEBRTCSIGNALING.fields_by_name['negotinationSuccessful'].message_type = _NEGOTINATIONSUCCESSFUL
_WEBRTCSIGNALING.fields_by_name['enableConnection'].message_type = _ENABLECONNECTION
_WEBRTCSIGNALING.fields_by_name['onRenegotiationNeeded'].message_type = _ONRENEGOTIATIONNEEDED
_WEBRTCSIGNALING.fields_by_name['closeSession'].message_type = _CLOSESESSION
_WEBRTCSIGNALING.fields_by_name['needDisconnect'].message_type = _NEEDDISCONNECT
_WEBRTCSIGNALING.fields_by_name['dTMF'].message_type = _DTMF
_WEBRTCSIGNALING.fields_by_name['callStats'].message_type = _CALLSTATS
_WEBRTCSIGNALING.fields_by_name['callNameChanged'].message_type = _CALLNAMECHANGED
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['advertiseSelf'])
_WEBRTCSIGNALING.fields_by_name['advertiseSelf'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['advertiseMaster'])
_WEBRTCSIGNALING.fields_by_name['advertiseMaster'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['advertisePeer'])
_WEBRTCSIGNALING.fields_by_name['advertisePeer'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['candidate'])
_WEBRTCSIGNALING.fields_by_name['candidate'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['gotICECandidate'])
_WEBRTCSIGNALING.fields_by_name['gotICECandidate'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['removedICECandidates'])
_WEBRTCSIGNALING.fields_by_name['removedICECandidates'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['offer'])
_WEBRTCSIGNALING.fields_by_name['offer'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['answer'])
_WEBRTCSIGNALING.fields_by_name['answer'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['needOffer'])
_WEBRTCSIGNALING.fields_by_name['needOffer'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['negotinationSuccessful'])
_WEBRTCSIGNALING.fields_by_name['negotinationSuccessful'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['enableConnection'])
_WEBRTCSIGNALING.fields_by_name['enableConnection'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['onRenegotiationNeeded'])
_WEBRTCSIGNALING.fields_by_name['onRenegotiationNeeded'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['closeSession'])
_WEBRTCSIGNALING.fields_by_name['closeSession'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['needDisconnect'])
_WEBRTCSIGNALING.fields_by_name['needDisconnect'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['dTMF'])
_WEBRTCSIGNALING.fields_by_name['dTMF'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['callStats'])
_WEBRTCSIGNALING.fields_by_name['callStats'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_WEBRTCSIGNALING.oneofs_by_name['body'].fields.append(
  _WEBRTCSIGNALING.fields_by_name['callNameChanged'])
_WEBRTCSIGNALING.fields_by_name['callNameChanged'].containing_oneof = _WEBRTCSIGNALING.oneofs_by_name['body']
_ADVERTISESELF.fields_by_name['peer_settings'].message_type = _PEERSETTINGS
_ADVERTISEMASTER.fields_by_name['server'].message_type = _ICESERVER
_ADVERTISEMASTER.fields_by_name['call_api_version'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_ADVERTISEMASTER.fields_by_name['call_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADVERTISEPEER.fields_by_name['peer_settings'].message_type = _PEERSETTINGS
_ADVERTISEPEER.fields_by_name['ice_servers'].message_type = _ICESERVER
_GOTICECANDIDATE.fields_by_name['candidate'].message_type = _ICECANDIDATE
_REMOVEDICECANDIDATES.fields_by_name['candidate'].message_type = _ICECANDIDATE
_OFFER.fields_by_name['peer_settings'].message_type = _PEERSETTINGS
_NEEDOFFER.fields_by_name['peer_settings'].message_type = _PEERSETTINGS
_DTMF.fields_by_name['code'].enum_type = _DTMFCODE
_CALLSTATS.fields_by_name['type'].enum_type = _CALLSTATSTYPE
_CALLNAMECHANGED.fields_by_name['call_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACTIVECALL.fields_by_name['peer'].message_type = peers__pb2._PEER
_ACTIVECALL.fields_by_name['call_members'].message_type = _CALLMEMBER
_CALLMEMBERSTATEHOLDER.fields_by_name['state'].enum_type = _CALLMEMBERSTATE
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_ringing'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_connected'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_connecting'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_ringing_reached'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_ended'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLMEMBER.fields_by_name['state'].message_type = _CALLMEMBERSTATEHOLDER
_PEERSETTINGS.fields_by_name['can_pre_connect'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PEERSETTINGS.fields_by_name['sends_offer'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PEERSETTINGS.fields_by_name['wait_for_candidates'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PEERSETTINGS.fields_by_name['client_info'].message_type = device__info__pb2._CLIENTINFO
DESCRIPTOR.message_types_by_name['UpdateIncomingCallDeprecated'] = _UPDATEINCOMINGCALLDEPRECATED
DESCRIPTOR.message_types_by_name['UpdateIncomingCall'] = _UPDATEINCOMINGCALL
DESCRIPTOR.message_types_by_name['UpdateCallHandled'] = _UPDATECALLHANDLED
DESCRIPTOR.message_types_by_name['UpdateCallDisposed'] = _UPDATECALLDISPOSED
DESCRIPTOR.message_types_by_name['RequestGetCallInfo'] = _REQUESTGETCALLINFO
DESCRIPTOR.message_types_by_name['ResponseGetCallInfo'] = _RESPONSEGETCALLINFO
DESCRIPTOR.message_types_by_name['CallLogEntry'] = _CALLLOGENTRY
DESCRIPTOR.message_types_by_name['RequestLoadCalls'] = _REQUESTLOADCALLS
DESCRIPTOR.message_types_by_name['ResponseLoadCalls'] = _RESPONSELOADCALLS
DESCRIPTOR.message_types_by_name['RequestDoCall'] = _REQUESTDOCALL
DESCRIPTOR.message_types_by_name['ResponseDoCall'] = _RESPONSEDOCALL
DESCRIPTOR.message_types_by_name['RequestJoinCall'] = _REQUESTJOINCALL
DESCRIPTOR.message_types_by_name['RequestRejectCall'] = _REQUESTREJECTCALL
DESCRIPTOR.message_types_by_name['RequestDeleteCall'] = _REQUESTDELETECALL
DESCRIPTOR.message_types_by_name['RequestChangeCallDisplayName'] = _REQUESTCHANGECALLDISPLAYNAME
DESCRIPTOR.message_types_by_name['ICEServer'] = _ICESERVER
DESCRIPTOR.message_types_by_name['ICECandidate'] = _ICECANDIDATE
DESCRIPTOR.message_types_by_name['WebRTCSignaling'] = _WEBRTCSIGNALING
DESCRIPTOR.message_types_by_name['AdvertiseSelf'] = _ADVERTISESELF
DESCRIPTOR.message_types_by_name['AdvertiseMaster'] = _ADVERTISEMASTER
DESCRIPTOR.message_types_by_name['AdvertisePeer'] = _ADVERTISEPEER
DESCRIPTOR.message_types_by_name['Candidate'] = _CANDIDATE
DESCRIPTOR.message_types_by_name['GotICECandidate'] = _GOTICECANDIDATE
DESCRIPTOR.message_types_by_name['RemovedICECandidates'] = _REMOVEDICECANDIDATES
DESCRIPTOR.message_types_by_name['Offer'] = _OFFER
DESCRIPTOR.message_types_by_name['Answer'] = _ANSWER
DESCRIPTOR.message_types_by_name['NeedOffer'] = _NEEDOFFER
DESCRIPTOR.message_types_by_name['NegotinationSuccessful'] = _NEGOTINATIONSUCCESSFUL
DESCRIPTOR.message_types_by_name['EnableConnection'] = _ENABLECONNECTION
DESCRIPTOR.message_types_by_name['OnRenegotiationNeeded'] = _ONRENEGOTIATIONNEEDED
DESCRIPTOR.message_types_by_name['CloseSession'] = _CLOSESESSION
DESCRIPTOR.message_types_by_name['NeedDisconnect'] = _NEEDDISCONNECT
DESCRIPTOR.message_types_by_name['DTMF'] = _DTMF
DESCRIPTOR.message_types_by_name['CallStats'] = _CALLSTATS
DESCRIPTOR.message_types_by_name['CallNameChanged'] = _CALLNAMECHANGED
DESCRIPTOR.message_types_by_name['ActiveCall'] = _ACTIVECALL
DESCRIPTOR.message_types_by_name['CallMemberStateHolder'] = _CALLMEMBERSTATEHOLDER
DESCRIPTOR.message_types_by_name['CallMember'] = _CALLMEMBER
DESCRIPTOR.message_types_by_name['PeerSettings'] = _PEERSETTINGS
DESCRIPTOR.enum_types_by_name['CallDisposedReason'] = _CALLDISPOSEDREASON
DESCRIPTOR.enum_types_by_name['RejectCallReason'] = _REJECTCALLREASON
DESCRIPTOR.enum_types_by_name['DTMFCode'] = _DTMFCODE
DESCRIPTOR.enum_types_by_name['CallStatsType'] = _CALLSTATSTYPE
DESCRIPTOR.enum_types_by_name['CallMemberState'] = _CALLMEMBERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpdateIncomingCallDeprecated = _reflection.GeneratedProtocolMessageType('UpdateIncomingCallDeprecated', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEINCOMINGCALLDEPRECATED,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateIncomingCallDeprecated)
  ))
_sym_db.RegisterMessage(UpdateIncomingCallDeprecated)

UpdateIncomingCall = _reflection.GeneratedProtocolMessageType('UpdateIncomingCall', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEINCOMINGCALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateIncomingCall)
  ))
_sym_db.RegisterMessage(UpdateIncomingCall)

UpdateCallHandled = _reflection.GeneratedProtocolMessageType('UpdateCallHandled', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECALLHANDLED,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateCallHandled)
  ))
_sym_db.RegisterMessage(UpdateCallHandled)

UpdateCallDisposed = _reflection.GeneratedProtocolMessageType('UpdateCallDisposed', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECALLDISPOSED,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateCallDisposed)
  ))
_sym_db.RegisterMessage(UpdateCallDisposed)

RequestGetCallInfo = _reflection.GeneratedProtocolMessageType('RequestGetCallInfo', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETCALLINFO,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetCallInfo)
  ))
_sym_db.RegisterMessage(RequestGetCallInfo)

ResponseGetCallInfo = _reflection.GeneratedProtocolMessageType('ResponseGetCallInfo', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETCALLINFO,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetCallInfo)
  ))
_sym_db.RegisterMessage(ResponseGetCallInfo)

CallLogEntry = _reflection.GeneratedProtocolMessageType('CallLogEntry', (_message.Message,), dict(
  DESCRIPTOR = _CALLLOGENTRY,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CallLogEntry)
  ))
_sym_db.RegisterMessage(CallLogEntry)

RequestLoadCalls = _reflection.GeneratedProtocolMessageType('RequestLoadCalls', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADCALLS,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadCalls)
  ))
_sym_db.RegisterMessage(RequestLoadCalls)

ResponseLoadCalls = _reflection.GeneratedProtocolMessageType('ResponseLoadCalls', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADCALLS,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadCalls)
  ))
_sym_db.RegisterMessage(ResponseLoadCalls)

RequestDoCall = _reflection.GeneratedProtocolMessageType('RequestDoCall', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTDOCALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDoCall)
  ))
_sym_db.RegisterMessage(RequestDoCall)

ResponseDoCall = _reflection.GeneratedProtocolMessageType('ResponseDoCall', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEDOCALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseDoCall)
  ))
_sym_db.RegisterMessage(ResponseDoCall)

RequestJoinCall = _reflection.GeneratedProtocolMessageType('RequestJoinCall', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTJOINCALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinCall)
  ))
_sym_db.RegisterMessage(RequestJoinCall)

RequestRejectCall = _reflection.GeneratedProtocolMessageType('RequestRejectCall', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTREJECTCALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRejectCall)
  ))
_sym_db.RegisterMessage(RequestRejectCall)

RequestDeleteCall = _reflection.GeneratedProtocolMessageType('RequestDeleteCall', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTDELETECALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeleteCall)
  ))
_sym_db.RegisterMessage(RequestDeleteCall)

RequestChangeCallDisplayName = _reflection.GeneratedProtocolMessageType('RequestChangeCallDisplayName', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTCHANGECALLDISPLAYNAME,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestChangeCallDisplayName)
  ))
_sym_db.RegisterMessage(RequestChangeCallDisplayName)

ICEServer = _reflection.GeneratedProtocolMessageType('ICEServer', (_message.Message,), dict(
  DESCRIPTOR = _ICESERVER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ICEServer)
  ))
_sym_db.RegisterMessage(ICEServer)

ICECandidate = _reflection.GeneratedProtocolMessageType('ICECandidate', (_message.Message,), dict(
  DESCRIPTOR = _ICECANDIDATE,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ICECandidate)
  ))
_sym_db.RegisterMessage(ICECandidate)

WebRTCSignaling = _reflection.GeneratedProtocolMessageType('WebRTCSignaling', (_message.Message,), dict(
  DESCRIPTOR = _WEBRTCSIGNALING,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.WebRTCSignaling)
  ))
_sym_db.RegisterMessage(WebRTCSignaling)

AdvertiseSelf = _reflection.GeneratedProtocolMessageType('AdvertiseSelf', (_message.Message,), dict(
  DESCRIPTOR = _ADVERTISESELF,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AdvertiseSelf)
  ))
_sym_db.RegisterMessage(AdvertiseSelf)

AdvertiseMaster = _reflection.GeneratedProtocolMessageType('AdvertiseMaster', (_message.Message,), dict(
  DESCRIPTOR = _ADVERTISEMASTER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AdvertiseMaster)
  ))
_sym_db.RegisterMessage(AdvertiseMaster)

AdvertisePeer = _reflection.GeneratedProtocolMessageType('AdvertisePeer', (_message.Message,), dict(
  DESCRIPTOR = _ADVERTISEPEER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AdvertisePeer)
  ))
_sym_db.RegisterMessage(AdvertisePeer)

Candidate = _reflection.GeneratedProtocolMessageType('Candidate', (_message.Message,), dict(
  DESCRIPTOR = _CANDIDATE,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Candidate)
  ))
_sym_db.RegisterMessage(Candidate)

GotICECandidate = _reflection.GeneratedProtocolMessageType('GotICECandidate', (_message.Message,), dict(
  DESCRIPTOR = _GOTICECANDIDATE,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GotICECandidate)
  ))
_sym_db.RegisterMessage(GotICECandidate)

RemovedICECandidates = _reflection.GeneratedProtocolMessageType('RemovedICECandidates', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEDICECANDIDATES,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RemovedICECandidates)
  ))
_sym_db.RegisterMessage(RemovedICECandidates)

Offer = _reflection.GeneratedProtocolMessageType('Offer', (_message.Message,), dict(
  DESCRIPTOR = _OFFER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Offer)
  ))
_sym_db.RegisterMessage(Offer)

Answer = _reflection.GeneratedProtocolMessageType('Answer', (_message.Message,), dict(
  DESCRIPTOR = _ANSWER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Answer)
  ))
_sym_db.RegisterMessage(Answer)

NeedOffer = _reflection.GeneratedProtocolMessageType('NeedOffer', (_message.Message,), dict(
  DESCRIPTOR = _NEEDOFFER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.NeedOffer)
  ))
_sym_db.RegisterMessage(NeedOffer)

NegotinationSuccessful = _reflection.GeneratedProtocolMessageType('NegotinationSuccessful', (_message.Message,), dict(
  DESCRIPTOR = _NEGOTINATIONSUCCESSFUL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.NegotinationSuccessful)
  ))
_sym_db.RegisterMessage(NegotinationSuccessful)

EnableConnection = _reflection.GeneratedProtocolMessageType('EnableConnection', (_message.Message,), dict(
  DESCRIPTOR = _ENABLECONNECTION,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.EnableConnection)
  ))
_sym_db.RegisterMessage(EnableConnection)

OnRenegotiationNeeded = _reflection.GeneratedProtocolMessageType('OnRenegotiationNeeded', (_message.Message,), dict(
  DESCRIPTOR = _ONRENEGOTIATIONNEEDED,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.OnRenegotiationNeeded)
  ))
_sym_db.RegisterMessage(OnRenegotiationNeeded)

CloseSession = _reflection.GeneratedProtocolMessageType('CloseSession', (_message.Message,), dict(
  DESCRIPTOR = _CLOSESESSION,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CloseSession)
  ))
_sym_db.RegisterMessage(CloseSession)

NeedDisconnect = _reflection.GeneratedProtocolMessageType('NeedDisconnect', (_message.Message,), dict(
  DESCRIPTOR = _NEEDDISCONNECT,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.NeedDisconnect)
  ))
_sym_db.RegisterMessage(NeedDisconnect)

DTMF = _reflection.GeneratedProtocolMessageType('DTMF', (_message.Message,), dict(
  DESCRIPTOR = _DTMF,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DTMF)
  ))
_sym_db.RegisterMessage(DTMF)

CallStats = _reflection.GeneratedProtocolMessageType('CallStats', (_message.Message,), dict(
  DESCRIPTOR = _CALLSTATS,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CallStats)
  ))
_sym_db.RegisterMessage(CallStats)

CallNameChanged = _reflection.GeneratedProtocolMessageType('CallNameChanged', (_message.Message,), dict(
  DESCRIPTOR = _CALLNAMECHANGED,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CallNameChanged)
  ))
_sym_db.RegisterMessage(CallNameChanged)

ActiveCall = _reflection.GeneratedProtocolMessageType('ActiveCall', (_message.Message,), dict(
  DESCRIPTOR = _ACTIVECALL,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ActiveCall)
  ))
_sym_db.RegisterMessage(ActiveCall)

CallMemberStateHolder = _reflection.GeneratedProtocolMessageType('CallMemberStateHolder', (_message.Message,), dict(
  DESCRIPTOR = _CALLMEMBERSTATEHOLDER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CallMemberStateHolder)
  ))
_sym_db.RegisterMessage(CallMemberStateHolder)

CallMember = _reflection.GeneratedProtocolMessageType('CallMember', (_message.Message,), dict(
  DESCRIPTOR = _CALLMEMBER,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CallMember)
  ))
_sym_db.RegisterMessage(CallMember)

PeerSettings = _reflection.GeneratedProtocolMessageType('PeerSettings', (_message.Message,), dict(
  DESCRIPTOR = _PEERSETTINGS,
  __module__ = 'web_rtc_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PeerSettings)
  ))
_sym_db.RegisterMessage(PeerSettings)


DESCRIPTOR._options = None
_UPDATEINCOMINGCALLDEPRECATED.fields_by_name['call_id']._options = None
_UPDATEINCOMINGCALLDEPRECATED.fields_by_name['attempt_index']._options = None
_UPDATEINCOMINGCALL.fields_by_name['call_id']._options = None
_UPDATEINCOMINGCALL.fields_by_name['event_bus_id']._options = None
_UPDATEINCOMINGCALL.fields_by_name['display_name']._options = None
_UPDATEINCOMINGCALL.fields_by_name['attempt_index']._options = None
_UPDATEINCOMINGCALL.fields_by_name['out_peer']._options = None
_UPDATEINCOMINGCALL.fields_by_name['video']._options = None
_UPDATECALLHANDLED.fields_by_name['call_id']._options = None
_UPDATECALLHANDLED.fields_by_name['attempt_index']._options = None
_UPDATECALLDISPOSED.fields_by_name['call_id']._options = None
_UPDATECALLDISPOSED.fields_by_name['attempt_index']._options = None
_REQUESTGETCALLINFO.fields_by_name['call_id']._options = None
_REQUESTGETCALLINFO._options = None
_RESPONSEGETCALLINFO._options = None
_CALLLOGENTRY.fields_by_name['id']._options = None
_CALLLOGENTRY.fields_by_name['call_date']._options = None
_CALLLOGENTRY.fields_by_name['initiator']._options = None
_CALLLOGENTRY.fields_by_name['recipient']._options = None
_CALLLOGENTRY.fields_by_name['duration']._options = None
_CALLLOGENTRY.fields_by_name['answered']._options = None
_CALLLOGENTRY.fields_by_name['display_name']._options = None
_REQUESTLOADCALLS.fields_by_name['next_offset']._options = None
_REQUESTLOADCALLS.fields_by_name['limit']._options = None
_REQUESTLOADCALLS._options = None
_RESPONSELOADCALLS._options = None
_REQUESTDOCALL.fields_by_name['peer']._options = None
_REQUESTDOCALL._options = None
_RESPONSEDOCALL._options = None
_REQUESTJOINCALL.fields_by_name['call_id']._options = None
_REQUESTJOINCALL._options = None
_REQUESTREJECTCALL.fields_by_name['call_id']._options = None
_REQUESTREJECTCALL._options = None
_REQUESTDELETECALL.fields_by_name['call_id']._options = None
_REQUESTDELETECALL._options = None
_REQUESTCHANGECALLDISPLAYNAME.fields_by_name['call_id']._options = None
_REQUESTCHANGECALLDISPLAYNAME.fields_by_name['display_name']._options = None
_REQUESTCHANGECALLDISPLAYNAME._options = None
_ICESERVER.fields_by_name['url']._options = None
_ICESERVER.fields_by_name['username']._options = None
_ICESERVER.fields_by_name['credential']._options = None
_ADVERTISESELF.fields_by_name['peer_settings']._options = None
_ADVERTISEMASTER.fields_by_name['server']._options = None
_ADVERTISEMASTER.fields_by_name['call_api_version']._options = None
_ADVERTISEPEER.fields_by_name['device_id']._options = None
_ADVERTISEPEER.fields_by_name['peer_settings']._options = None
_ADVERTISEPEER.fields_by_name['ice_servers']._options = None
_CANDIDATE.fields_by_name['session_id']._options = None
_CANDIDATE.fields_by_name['index']._options = None
_CANDIDATE.fields_by_name['id']._options = None
_CANDIDATE.fields_by_name['sdp']._options = None
_OFFER.fields_by_name['session_id']._options = None
_OFFER.fields_by_name['sdp']._options = None
_OFFER.fields_by_name['peer_settings']._options = None
_ANSWER.fields_by_name['session_id']._options = None
_ANSWER.fields_by_name['sdp']._options = None
_NEEDOFFER.fields_by_name['device']._options = None
_NEEDOFFER.fields_by_name['session_id']._options = None
_NEEDOFFER.fields_by_name['peer_settings']._options = None
_NEGOTINATIONSUCCESSFUL.fields_by_name['device']._options = None
_NEGOTINATIONSUCCESSFUL.fields_by_name['session_id']._options = None
_ENABLECONNECTION.fields_by_name['device']._options = None
_ENABLECONNECTION.fields_by_name['session_id']._options = None
_ONRENEGOTIATIONNEEDED.fields_by_name['device']._options = None
_ONRENEGOTIATIONNEEDED.fields_by_name['session_id']._options = None
_CLOSESESSION.fields_by_name['device']._options = None
_CLOSESESSION.fields_by_name['session_id']._options = None
_NEEDDISCONNECT.fields_by_name['device']._options = None
_DTMF.fields_by_name['code']._options = None
_DTMF.fields_by_name['duration']._options = None
_CALLSTATS.fields_by_name['type']._options = None
_CALLSTATS.fields_by_name['value']._options = None
_ACTIVECALL.fields_by_name['call_id']._options = None
_ACTIVECALL.fields_by_name['peer']._options = None
_ACTIVECALL.fields_by_name['call_members']._options = None
_CALLMEMBERSTATEHOLDER.fields_by_name['state']._options = None
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_ringing']._options = None
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_connected']._options = None
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_connecting']._options = None
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_ringing_reached']._options = None
_CALLMEMBERSTATEHOLDER.fields_by_name['fallback_is_ended']._options = None
_CALLMEMBER.fields_by_name['user_id']._options = None
_CALLMEMBER.fields_by_name['state']._options = None
_PEERSETTINGS.fields_by_name['can_pre_connect']._options = None
_PEERSETTINGS.fields_by_name['sends_offer']._options = None
_PEERSETTINGS.fields_by_name['wait_for_candidates']._options = None
_PEERSETTINGS.fields_by_name['client_info']._options = None

_WEBRTC = _descriptor.ServiceDescriptor(
  name='WebRTC',
  full_name='dialog.WebRTC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7872,
  serialized_end=8624,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCallInfo',
    full_name='dialog.WebRTC.GetCallInfo',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETCALLINFO,
    output_type=_RESPONSEGETCALLINFO,
    serialized_options=_b('\202\323\344\223\002 \"\033/v1/grpc/WebRTC/GetCallInfo:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadCalls',
    full_name='dialog.WebRTC.LoadCalls',
    index=1,
    containing_service=None,
    input_type=_REQUESTLOADCALLS,
    output_type=_RESPONSELOADCALLS,
    serialized_options=_b('\202\323\344\223\002\036\"\031/v1/grpc/WebRTC/LoadCalls:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DoCall',
    full_name='dialog.WebRTC.DoCall',
    index=2,
    containing_service=None,
    input_type=_REQUESTDOCALL,
    output_type=_RESPONSEDOCALL,
    serialized_options=_b('\202\323\344\223\002\033\"\026/v1/grpc/WebRTC/DoCall:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='JoinCall',
    full_name='dialog.WebRTC.JoinCall',
    index=3,
    containing_service=None,
    input_type=_REQUESTJOINCALL,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002\035\"\030/v1/grpc/WebRTC/JoinCall:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RejectCall',
    full_name='dialog.WebRTC.RejectCall',
    index=4,
    containing_service=None,
    input_type=_REQUESTREJECTCALL,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/grpc/WebRTC/RejectCall:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ChangeCallDisplayName',
    full_name='dialog.WebRTC.ChangeCallDisplayName',
    index=5,
    containing_service=None,
    input_type=_REQUESTCHANGECALLDISPLAYNAME,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002*\"%/v1/grpc/WebRTC/ChangeCallDisplayName:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCall',
    full_name='dialog.WebRTC.DeleteCall',
    index=6,
    containing_service=None,
    input_type=_REQUESTDELETECALL,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/grpc/WebRTC/DeleteCall:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBRTC)

DESCRIPTOR.services_by_name['WebRTC'] = _WEBRTC

# @@protoc_insertion_point(module_scope)
